package com.ruoyi.project.base.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.project.base.domain.TBaseRegion;
import com.ruoyi.project.base.service.ITBaseRegionService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.Date;
import java.util.List;

/**
 * 区域Controller
 *
 * @author ruoyi
 * @date 2022-11-14
 */
@RestController
@RequestMapping("/base/region")
public class TBaseRegionController extends BaseController
{
    @Autowired
    private ITBaseRegionService tBaseRegionService;

    /**
     * 查询区域列表
     */
    @PreAuthorize("@ss.hasPermi('base:region:list')")
    @GetMapping("/list")
    public TableDataInfo list(TBaseRegion tBaseRegion)
    {
        startPage();
        List<TBaseRegion> list = tBaseRegionService.selectTBaseRegionList(tBaseRegion);
        return getDataTable(list);
    }

    @GetMapping("/allRegion/{plantId}")
    public AjaxResult allRegion(@PathVariable("plantId") Long plantId)
    {
        return AjaxResult.success(tBaseRegionService.selectAllRegionByPlantId(plantId));
    }

    /**
     * 导出区域列表
     */
    @PreAuthorize("@ss.hasPermi('base:region:export')")
    @Log(title = "区域", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TBaseRegion tBaseRegion)
    {
        List<TBaseRegion> list = tBaseRegionService.selectTBaseRegionList(tBaseRegion);
        ExcelUtil<TBaseRegion> util = new ExcelUtil<TBaseRegion>(TBaseRegion.class);
        util.exportExcel(response, list, "区域数据");
    }

    /**
     * 获取区域详细信息
     */
    @PreAuthorize("@ss.hasPermi('base:region:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(tBaseRegionService.selectTBaseRegionById(id));
    }

    /**
     * 新增区域
     */
    @PreAuthorize("@ss.hasPermi('base:region:add')")
    @Log(title = "区域", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TBaseRegion tBaseRegion)
    {
        tBaseRegion.setCreaterCode(getUserId());
        tBaseRegion.setUpdaterCode(getUserId());
        tBaseRegion.setUpdatedate(new Date());
        return toAjax(tBaseRegionService.insertTBaseRegion(tBaseRegion));
    }

    /**
     * 修改区域
     */
    @PreAuthorize("@ss.hasPermi('base:region:edit')")
    @Log(title = "区域", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TBaseRegion tBaseRegion)
    {
        tBaseRegion.setUpdaterCode(getUserId());
        tBaseRegion.setUpdatedate(new Date());
        return toAjax(tBaseRegionService.updateTBaseRegion(tBaseRegion));
    }

    /**
     * 删除区域
     */
    @PreAuthorize("@ss.hasPermi('base:region:remove')")
    @Log(title = "区域", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tBaseRegionService.deleteTBaseRegionByIds(ids));
    }
}
