package com.ruoyi.project.check.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.project.check.domain.TCheckEnvironment;
import com.ruoyi.project.check.service.ITCheckEnvironmentService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.*;

/**
 * 环境本底值记录Controller
 *
 * @author ruoyi
 * @date 2022-11-24
 */
@RestController
@RequestMapping("/check/environment")
public class TCheckEnvironmentController extends BaseController
{
    @Autowired
    private ITCheckEnvironmentService tCheckEnvironmentService;

    /**
     * 查询环境本底值记录列表
     */
    @PreAuthorize("@ss.hasPermi('check:environment:list')")
    @GetMapping("/list")
    public TableDataInfo list(TCheckEnvironment tCheckEnvironment)
    {
        startPage();
        List<TCheckEnvironment> list = tCheckEnvironmentService.selectTCheckEnvironmentList(tCheckEnvironment);
        return getDataTable(list);
    }

    /**
     * 导出环境本底值记录列表
     */
    @PreAuthorize("@ss.hasPermi('check:environment:export')")
    @Log(title = "环境本底值记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TCheckEnvironment tCheckEnvironment)
    {
        List<TCheckEnvironment> list = tCheckEnvironmentService.selectTCheckEnvironmentList(tCheckEnvironment);
        ExcelUtil<TCheckEnvironment> util = new ExcelUtil<TCheckEnvironment>(TCheckEnvironment.class);
        util.exportExcel(response, list, "环境本底值记录数据");
    }

    /**
     * 获取环境本底值记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('check:environment:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(tCheckEnvironmentService.selectTCheckEnvironmentById(id));
    }

    /**
     * 新增环境本底值记录
     */
    @PreAuthorize("@ss.hasPermi('check:environment:add')")
    @Log(title = "环境本底值记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TCheckEnvironment tCheckEnvironment)
    {
        tCheckEnvironment.setUpdatedate(new Date());
        tCheckEnvironment.setUpdaterCode(getUserId());
        tCheckEnvironment.setCreaterCode(getUserId());
        return toAjax(tCheckEnvironmentService.insertTCheckEnvironment(tCheckEnvironment));
    }

    /**
     * 修改环境本底值记录
     */
    @PreAuthorize("@ss.hasPermi('check:environment:edit')")
    @Log(title = "环境本底值记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TCheckEnvironment tCheckEnvironment)
    {
        tCheckEnvironment.setUpdatedate(new Date());
        tCheckEnvironment.setUpdaterCode(getUserId());
        return toAjax(tCheckEnvironmentService.updateTCheckEnvironment(tCheckEnvironment));
    }

    /**
     * 删除环境本底值记录
     */
    @PreAuthorize("@ss.hasPermi('check:environment:remove')")
    @Log(title = "环境本底值记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tCheckEnvironmentService.deleteTCheckEnvironmentByIds(ids));
    }

    public static void main(String[] args) {
        int piles[]={1,2,3,4};
        int max = Arrays.stream(piles).max().getAsInt();
        System.out.println(max);
    }
}
