package com.ruoyi.project.task.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.project.task.domain.TTaskInspection;
import com.ruoyi.project.task.domain.TTaskInspectionPlan;
import com.ruoyi.project.task.service.ITTaskInspectionPlanService;
import com.ruoyi.project.task.service.ITTaskInspectionService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;

/**
 * 检测任务Controller
 *
 * @author ruoyi
 * @date 2022-11-21
 */
@RestController
@RequestMapping("/task/inspection")
public class TTaskInspectionController extends BaseController {
    @Autowired
    private ITTaskInspectionService tTaskInspectionService;

    @Autowired
    private ITTaskInspectionPlanService taskInspectionPlanService;

    /**
     * 查询检测任务列表
     */
    @PreAuthorize("@ss.hasPermi('task:inspection:list')")
    @GetMapping("/list")
    public TableDataInfo list(TTaskInspection tTaskInspection) {
        startPage();
        List<TTaskInspection> list = tTaskInspectionService.selectTTaskInspectionList(tTaskInspection);
        list.forEach(item -> {
            if (StringUtils.isNotEmpty(item.getTaskDoneNum()) && StringUtils.isNotEmpty(item.getTaskNum())) {
                item.setPercentage(new BigDecimal(item.getTaskDoneNum()).divide(new BigDecimal(item.getTaskNum()), 4, RoundingMode.HALF_UP).multiply(new BigDecimal(100)).doubleValue());
            }
            if (item.getEndTime() != null) {
                if (item.getEndTime().before(new Date())) {
                    item.setTimeOut("是");
                } else {
                    item.setTimeOut("否");
                }
            }
        });
        return getDataTable(list);
    }

    /**
     * 导出检测任务列表
     */
    @PreAuthorize("@ss.hasPermi('task:inspection:export')")
    @Log(title = "检测任务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TTaskInspection tTaskInspection) {
        List<TTaskInspection> list = tTaskInspectionService.selectTTaskInspectionList(tTaskInspection);
        ExcelUtil<TTaskInspection> util = new ExcelUtil<TTaskInspection>(TTaskInspection.class);
        util.exportExcel(response, list, "检测任务数据");
    }

    /**
     * 获取检测任务详细信息
     */
    @PreAuthorize("@ss.hasPermi('task:inspection:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return AjaxResult.success(tTaskInspectionService.selectTTaskInspectionById(id));
    }

    /**
     * 新增检测任务
     */
    @PreAuthorize("@ss.hasPermi('task:inspection:add')")
    @Log(title = "检测任务", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TTaskInspection tTaskInspection) {
        TTaskInspectionPlan tTaskInspectionPlan = taskInspectionPlanService.selectTTaskInspectionPlanById(tTaskInspection.getPlanId());
        tTaskInspection.setPlantId(tTaskInspectionPlan.getPlantId());
        tTaskInspection.setCreaterCode(getUserId());
        return toAjax(tTaskInspectionService.insertTTaskInspection(tTaskInspection));
    }

    /**
     * 修改检测任务
     */
    @PreAuthorize("@ss.hasPermi('task:inspection:edit')")
    @Log(title = "检测任务", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TTaskInspection tTaskInspection) {
        TTaskInspectionPlan tTaskInspectionPlan = taskInspectionPlanService.selectTTaskInspectionPlanById(tTaskInspection.getPlanId());
        tTaskInspection.setPlantId(tTaskInspectionPlan.getPlantId());
        tTaskInspection.setUpdaterCode(getUserId());
        return toAjax(tTaskInspectionService.updateTTaskInspection(tTaskInspection));
    }

    /**
     * 删除检测任务
     */
    @PreAuthorize("@ss.hasPermi('task:inspection:remove')")
    @Log(title = "检测任务", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tTaskInspectionService.deleteTTaskInspectionByIds(ids));
    }

    @PreAuthorize("@ss.hasPermi('task:inspection:edit')")
    @Log(title = "检测任务分配", businessType = BusinessType.UPDATE)
    @PutMapping("/{ids}")
    public AjaxResult divide(@PathVariable Long[] ids) {
        return toAjax(tTaskInspectionService.updateTTaskInspectionByIds(ids));
    }
}
