package com.ruoyi.project.task.controller;

import java.sql.Time;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.project.base.domain.TBasePlant;
import com.ruoyi.project.base.domain.TBasePoint;
import com.ruoyi.project.base.mapper.TBasePointMapper;
import com.ruoyi.project.base.service.ITBasePlantService;
import com.ruoyi.project.base.service.ITBasePointService;
import com.ruoyi.project.task.mapper.TTaskInspectionPlanMapper;
import com.ruoyi.system.service.ISysDictTypeService;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.project.task.domain.TTaskInspectionPlan;
import com.ruoyi.project.task.service.ITTaskInspectionPlanService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 检测计划Controller
 *
 * @author ruoyi
 * @date 2022-11-17
 */
@RestController
@RequestMapping("/task/plan")
public class TTaskInspectionPlanController extends BaseController {
    @Autowired
    private ITTaskInspectionPlanService tTaskInspectionPlanService;

    @Autowired
    private TTaskInspectionPlanMapper tTaskInspectionPlanMapper;

    @Autowired
    private ITBasePlantService tBasePlantService;

    @Autowired
    private ISysDictTypeService isysDictTypeService;

    @Autowired
    private TBasePointMapper tBasePointMapper;

    /**
     * 查询检测计划列表
     */
    @PreAuthorize("@ss.hasPermi('task:plan:list')")
    @GetMapping("/list")
    public TableDataInfo list(TTaskInspectionPlan tTaskInspectionPlan) {
        startPage();
        List<TTaskInspectionPlan> list = tTaskInspectionPlanService.selectTTaskInspectionPlanList(tTaskInspectionPlan);
        return getDataTable(list);
    }

    @GetMapping("/allPlan")
    public AjaxResult selectAllPlan() {
        return AjaxResult.success(tTaskInspectionPlanService.selectAllPlan());
    }

    /**
     * 导出检测计划列表
     */
    @PreAuthorize("@ss.hasPermi('task:plan:export')")
    @Log(title = "检测计划", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TTaskInspectionPlan tTaskInspectionPlan) {
        List<TTaskInspectionPlan> list = tTaskInspectionPlanService.selectTTaskInspectionPlanList(tTaskInspectionPlan);
        ExcelUtil<TTaskInspectionPlan> util = new ExcelUtil<TTaskInspectionPlan>(TTaskInspectionPlan.class);
        util.exportExcel(response, list, "检测计划数据");
    }

    /**
     * 获取检测计划详细信息
     */
    @PreAuthorize("@ss.hasPermi('task:plan:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return AjaxResult.success(tTaskInspectionPlanService.selectTTaskInspectionPlanById(id));
    }

    /**
     * 新增检测计划
     */
    @PreAuthorize("@ss.hasPermi('task:plan:add')")
    @Log(title = "检测计划", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TTaskInspectionPlan tTaskInspectionPlan) {
        tTaskInspectionPlan.setCreaterCode(getUserId());
        return toAjax(tTaskInspectionPlanService.insertTTaskInspectionPlan(tTaskInspectionPlan));
    }

    @PreAuthorize("@ss.hasPermi('task:plan:add')")
    @Log(title = "校验检测计划", businessType = BusinessType.INSERT)
    @PostMapping("/checkPlan")
    public AjaxResult checkPlan() {
        List<TTaskInspectionPlan> tTaskInspectionPlans = new ArrayList<>();
        int nowQuarter = DateUtils.getNowQuarter(); // 获取当前季度
        Calendar calendar = Calendar.getInstance(); // 获取当前时间
        String year = String.valueOf(calendar.get(Calendar.YEAR)); // 获取当前年份
        for (TBasePlant tBasePlant : tBasePlantService.selectAllPlantName()) {// 查询已审核所有装置
            // 查询今年当前季度是否有监测计划
            QueryWrapper<TTaskInspectionPlan> plansWrapper = new QueryWrapper<TTaskInspectionPlan>().eq("year", year).eq("quarter", nowQuarter).eq("plant_id", tBasePlant.getId()).eq("del_flag", 0);
            List<TTaskInspectionPlan> plans = tTaskInspectionPlanService.list(plansWrapper);
            if (CollectionUtils.isNotEmpty(plans)) {// 有则跳过
                continue;
            }
            TTaskInspectionPlan tTaskInspectionPlan = new TTaskInspectionPlan();
            tTaskInspectionPlan.setPlantId(tBasePlant.getId());
            // 查询最后一个计划编号
            plansWrapper.clear();
            plansWrapper.eq("del_flag", 0).orderByDesc("code");
            plans = tTaskInspectionPlanMapper.selectList(plansWrapper);
            int code = 0;
            if (CollectionUtils.isNotEmpty(plans)) {
                code = plans.get(0).getCode() + 1;// 当前计划编号为前一个计划编号+1
            }
            // 检测计划编号
            tTaskInspectionPlan.setInspectionPlanNo("LTP_" + year + "_" + "0" + nowQuarter + "_" + code);
            // 检测计划名称
            tTaskInspectionPlan.setInspectionPlanName(tBasePlant.getPlantName() + "_" + year + "第" + nowQuarter + "季度检测计划");
            if (nowQuarter == 1 && nowQuarter == 3) {
                // 当前季度为1、3季度时，检测频次为一季一次
                // TODO 当装置中没有动密封点时，跳过此计划
                tTaskInspectionPlan.setDetectionFrequency("2");
                // 检测结束时间为开始时间+3个月
                tTaskInspectionPlan.setEndTime(DateUtils.addTime(new Date(), Calendar.MONTH, 3));
            } else {
                // 当前季度为2、4季度时，检测频次为半年一次
                tTaskInspectionPlan.setDetectionFrequency("3");
                // 检测结束时间为开始时间+6个月
                tTaskInspectionPlan.setEndTime(DateUtils.addTime(new Date(), Calendar.MONTH, 6));
            }
            // 检测开始时间 TODO:改成传过来的
            tTaskInspectionPlan.setStartTime(new Date());
            // 统计当前装置下的所有(动)密封点
            QueryWrapper<TBasePoint> points = new QueryWrapper<TBasePoint>().eq("plant_id", tBasePlant.getId()).eq("del_flag", 0).eq("approve_status", 2);
            // TODO: 当1、3季度时需要加上动密封点的判断
//            if (nowQuarter == 1 && nowQuarter == 3) {
//                points.eq("","");
//            }
            Integer count = tBasePointMapper.selectCount(points);
            tTaskInspectionPlan.setPointNum(count.toString());
            tTaskInspectionPlan.setCreaterCode(getUserId());
            tTaskInspectionPlan.setCreatedate(new Date());
            tTaskInspectionPlan.setUpdaterCode(getUserId());
            tTaskInspectionPlan.setUpdatedate(new Date());
            tTaskInspectionPlan.setCode(code);
            tTaskInspectionPlan.setYear(year);
            tTaskInspectionPlan.setQuarter(String.valueOf(nowQuarter));
            tTaskInspectionPlans.add(tTaskInspectionPlan);
        }
        if (!tTaskInspectionPlans.isEmpty()) {
            return toAjax(tTaskInspectionPlanService.insertTTaskInspectionPlanByList(tTaskInspectionPlans));
        }
        return AjaxResult.success();
    }


    /**
     * 修改检测计划
     */
    @PreAuthorize("@ss.hasPermi('task:plan:edit')")
    @Log(title = "检测计划", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TTaskInspectionPlan tTaskInspectionPlan) {
        tTaskInspectionPlan.setUpdaterCode(getUserId());
        return toAjax(tTaskInspectionPlanService.updateTTaskInspectionPlan(tTaskInspectionPlan));
    }

    /**
     * 删除检测计划
     */
    @PreAuthorize("@ss.hasPermi('task:plan:remove')")
    @Log(title = "检测计划", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tTaskInspectionPlanService.deleteTTaskInspectionPlanByIds(ids));
    }
}
